@@ -41,8 +41,6 @@
 
 #define BALOO_CORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(BALOO_CORE_NO_DEPRECATED) && !defined(BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define BALOO_CORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef BALOO_CORE_NO_DEPRECATED
-#  define BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef BALOO_CORE_NO_DEPRECATED_WARNINGS
 #  define BALOO_CORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define BALOO_CORE_DEPRECATED_WARNINGS_SINCE BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define BALOO_CORE_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define BALOO_CORE_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef BALOO_CORE_DEPRECATED
-#  define BALOO_CORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define BALOO_CORE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define BALOO_CORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
